@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Productions parser used by css and stylesheets classes to parse
 test into a cssutils.util.Seq and at the same time retrieving
 additional specific cssutils.util.Item objects for later use.
@@ -54,7 +53,7 @@ class NoMatch(ParseError):
     pass
 
 
-class Choice(object):
+class Choice:
     """A Choice of productions (Sequence or single Prod)."""
 
     def __init__(self, *prods, **options):
@@ -113,13 +112,13 @@ class Choice(object):
             else:
                 if not optional:
                     # None matched but also None is optional
-                    raise NoMatch('No match for %s in %s' % (token, self))
+                    raise NoMatch(f'No match for {token} in {self}')
                     # raise ParseError(u'No match in %s for %s' % (self, token))
         elif token:
             raise Exhausted('Extra token')
 
     def __repr__(self):
-        return "<cssutils.prodsparser.%s object sequence=%r optional=%r at 0x%x>" % (
+        return "<cssutils.prodsparser.{} object sequence={!r} optional={!r} at 0x{:x}>".format(
             self.__class__.__name__,
             self.__str__(),
             self.optional,
@@ -130,7 +129,7 @@ class Choice(object):
         return 'Choice(%s)' % ', '.join([str(x) for x in self._prods])
 
 
-class Sequence(object):
+class Sequence:
     """A Sequence of productions (Choice or single Prod)."""
 
     def __init__(self, *prods, **options):
@@ -234,13 +233,13 @@ class Sequence(object):
                     raise Done()
 
             else:
-                raise NoMatch('No match for %s in %s' % (token, self))
+                raise NoMatch(f'No match for {token} in {self}')
 
         if token:
             raise Exhausted('Extra token')
 
     def __repr__(self):
-        return "<cssutils.prodsparser.%s object sequence=%r optional=%r at 0x%x>" % (
+        return "<cssutils.prodsparser.{} object sequence={!r} optional={!r} at 0x{:x}>".format(
             self.__class__.__name__,
             self.__str__(),
             self.optional,
@@ -251,7 +250,7 @@ class Sequence(object):
         return 'Sequence(%s)' % ', '.join([str(x) for x in self._prods])
 
 
-class Prod(object):
+class Prod:
     """Single Prod in Sequence or Choice."""
 
     def __init__(
@@ -360,7 +359,7 @@ class Prod(object):
         return self._name
 
     def __repr__(self):
-        return "<cssutils.prodsparser.%s object name=%r at 0x%x>" % (
+        return "<cssutils.prodsparser.{} object name={!r} at 0x{:x}>".format(
             self.__class__.__name__,
             self._name,
             id(self),
@@ -374,7 +373,7 @@ tokenizer = cssutils.tokenize2.Tokenizer()
 savedTokens = []
 
 
-class ProdParser(object):
+class ProdParser:
     """Productions parser."""
 
     def __init__(self, clear=True):
@@ -543,7 +542,7 @@ class ProdParser(object):
             elif type_ == self.types.INVALID:
                 # invalidate parse
                 wellformed = False
-                self._log.error('Invalid token: %r' % (token,))
+                self._log.error(f'Invalid token: {token!r}')
                 break
 
             elif type_ == 'EOF':
@@ -584,7 +583,7 @@ class ProdParser(object):
 
                     else:
                         wellformed = False
-                        self._log.error('%s: %s: %r' % (name, e, token))
+                        self._log.error(f'{name}: {e}: {token!r}')
                     break
 
                 except ParseError as e:
@@ -596,7 +595,7 @@ class ProdParser(object):
 
                     else:
                         wellformed = False
-                        self._log.error('%s: %s: %r' % (name, e, token))
+                        self._log.error(f'{name}: {e}: {token!r}')
                     break
 
                 else:
@@ -661,12 +660,12 @@ class ProdParser(object):
                     # last was a S operator which may End a Sequence, then ok
                     if hasattr(lastprod, 'mayEnd') and not lastprod.mayEnd:
                         wellformed = False
-                        self._log.error('%s: %s' % (name, e))
+                        self._log.error(f'{name}: {e}')
 
                 except ParseError as e:
                     prod = None
                     wellformed = False
-                    self._log.error('%s: %s' % (name, e))
+                    self._log.error(f'{name}: {e}')
 
                 else:
                     if prods[-1].optional:
@@ -678,7 +677,7 @@ class ProdParser(object):
                 if prod and not prod.optional:
                     wellformed = False
                     self._log.error(
-                        '%s: Missing token for production %r' % (name, str(prod))
+                        f'{name}: Missing token for production {str(prod)!r}'
                     )
                     break
                 elif len(prods) > 1:
@@ -696,7 +695,7 @@ class ProdParser(object):
         return wellformed, seq, store, tokens
 
 
-class PreDef(object):
+class PreDef:
     """Predefined Prod definition for use in productions definition
     for ProdParser instances.
     """
