@@ -1,31 +1,5 @@
-# -*- coding: utf-8 -*-
 """encutils - encoding detection collection for Python
 
-:Version: 0.9.8
-:Author: Christof Hoeke, see http://cthedot.de/encutils/
-:Contributor: Robert Siemer, Fredrik Hedman <fredrik.hedman@me.com> ported to python3
-:Copyright: 2005-2012: Christof Hoeke
-:License: encutils has a dual-license, please choose whatever you prefer:
-
-    * encutils is published under the
-      `LGPL 3 or later <http://cthedot.de/encutils/license/>`__
-    * encutils is published under the
-      `Creative Commons License <http://creativecommons.org/licenses/by/3.0/>`__.
-
-    encutils is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    encutils is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with encutils.  If not, see <http://www.gnu.org/licenses/>.
-
-
 A collection of helper functions to detect encodings of text files
 (like HTML, XHTML, XML, CSS, etc.) retrieved via HTTP, file or string.
 
@@ -93,7 +67,7 @@ class _MetaHTMLParser(html.parser.HTMLParser):
 
     def handle_starttag(self, tag, attrs):
         if tag == 'meta' and not self.content_type:
-            atts = dict([(a.lower(), v.lower()) for a, v in attrs])
+            atts = {a.lower(): v.lower() for a, v in attrs}
             if atts.get('http-equiv', '').strip() == 'content-type':
                 self.content_type = atts.get('content')
 
@@ -119,7 +93,7 @@ _TEXT_UTF8 = 5
 _OTHER_TYPE = 4
 
 
-class EncodingInfo(object):
+class EncodingInfo:
     """
     All encoding related information, returned by :func:`getEncodingInfo`.
 
@@ -173,7 +147,7 @@ class EncodingInfo(object):
             return ''
 
     def __repr__(self):
-        return "<%s.%s object encoding=%r mismatch=%s at 0x%x>" % (
+        return "<{}.{} object encoding={!r} mismatch={} at 0x{:x}>".format(
             self.__class__.__module__,
             self.__class__.__name__,
             self.encoding,
@@ -595,7 +569,7 @@ def getEncodingInfo(response=None, text='', log=None, url=None):  # noqa: C901
         # read text from response only if not explicitly given
         try:
             text = response.read()
-        except IOError:
+        except OSError:
             pass
 
     if text is None:
